# Automated Trading

[![PyPI Latest Release](https://img.shields.io/pypi/v/algotradepy.svg)](https://pypi.org/project/algotradepy/)
[![Build Status](https://travis-ci.com/petioptrv/automated-trading.svg?branch=master)](https://travis-ci.com/petioptrv/automated-trading)
[![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg )](https://raw.githubusercontent.com/petioptrv/automated-trading/cicd-fixes/LICENSE.txt)

This repository hosts `algotradepy`, a Python framework for automated trading 
tools.

## Credits

Sources for individually adapted files are provided within the files 
themselves. The following are sources that have influenced mutliple files in 
this repository.

[1] [Flake-8 & Black integration.](https://ljvmiranda921.github.io/notebook/2018/06/21/precommits-using-black-and-flake8/)